api
===

.. currentmodule:: ndpyramid


Top level API
~~~~~~~~~~~~~

.. autosummary::
   :toctree: generated/

   pyramid_coarsen
   pyramid_create
   pyramid_reproject
   pyramid_regrid
   pyramid_resample
